@@ -5,23 +5,27 @@ from robot.utils import get_link_path
 
 
 def get_log_directory():
-    """Get output directory from robot framework built in variables if not exists fallback to os path execution"""
+    """
+    Get output directory from robot framework built in variables if not exists fallback to os path execution
+    """
     try:
         return BuiltIn().get_variable_value("${OUTPUT DIR}")
     except RobotNotRunningError:
         return os.getcwd()
 
 
-def log(message):
-    """Log given message to robot result.
+def log(message: str):
+    """
+    Log given message to robot result.
 
     ``message`` Message to log to robot.
     """
     logger.info(message)
 
 
-def log_screenshot(filepath):
-    """Append testing log by a screenshot
+def log_screenshot(filepath: str):
+    """
+    Append testing log by a screenshot
 
     ``filepath`` Filepath from stored screenshot.
     """
